@@ -37,7 +37,7 @@ def plot(varx   : InVar | OutVar,
          plotkwargs  : dict           = dict(),
          ) -> tuple[Figure, Axes]:
     """
-    Umbrella function to make single plots of a single Monte-Carlo variable or
+    Umbrella function to make single plots of a single Monte Carlo variable or
     pairs or triplets of variables.
 
     Parameters
@@ -202,12 +202,17 @@ def plot_hist(var         : InVar | OutVar,
     fig, ax = manage_axis(ax, is3d=False)
     invar_space = manage_invar_space(invar_space=invar_space, nvars=1)
 
+    bins = 'auto'
+    if 'bins' in plotkwargs:
+        bins = plotkwargs['bins']
+        del(plotkwargs['bins'])
+
     # Histogram generation
     cases_list = get_cases(var.ncases, cases)
     highlight_cases_list = get_cases(var.ncases, highlight_cases)
     points = get_plot_points(var, invar_space[0])
     nums = slice_by_index(points, cases_list)
-    counts, bins = np.histogram(nums, bins='auto')
+    counts, bins = np.histogram(nums, bins=bins)
     binwidth = mode(np.diff(bins))[0]
     bins = np.concatenate((bins - binwidth/2, bins[-1] + binwidth/2))
     counts, bins = np.histogram(nums, bins=bins)
@@ -215,7 +220,7 @@ def plot_hist(var         : InVar | OutVar,
     if isinstance(var, monaco.mc_var.InVar):
         # Continuous distribution
         if isinstance(var.dist, rv_continuous):
-            plt.hist(bins[:-1], bins, weights=counts/sum(counts), density=True,
+            plt.hist(bins[:-1], bins=bins, weights=counts/sum(counts), density=True,
                      cumulative=cumulative, orientation=orientation, histtype='bar',
                      facecolor='k', alpha=0.5, **plotkwargs)
             lim = get_hist_lim(ax, orientation)
@@ -232,25 +237,28 @@ def plot_hist(var         : InVar | OutVar,
 
         # Discrete distribution
         elif isinstance(var.dist, rv_discrete):
-            plt.hist(bins[:-1], bins, weights=counts/sum(counts), density=False,
+            plt.hist(bins[:-1], bins=bins, weights=counts/sum(counts), density=False,
                      orientation=orientation, cumulative=cumulative, histtype='bar',
                      facecolor='k', alpha=0.5, **plotkwargs)
             lim = get_hist_lim(ax, orientation)
-            x = np.concatenate(([lim[0]], bins, [lim[1]]))
+            x = np.arange(int(np.floor(lim[0])), int(np.ceil(lim[1])))
             dist = var.dist(**var.distkwargs)
+            xdata = x
             if cumulative:
-                xdata = x - binwidth
                 ydata = dist.cdf(x)
+                if orientation == PlotOrientation.VERTICAL:
+                    plt.step(xdata, ydata, color='k', alpha=0.9, where='post')
+                elif orientation == PlotOrientation.HORIZONTAL:
+                    plt.step(ydata, xdata, color='k', alpha=0.9, where='post')
             else:
-                xdata = x[1:]
-                ydata = np.diff(dist.cdf(x))  # manual pdf
-            if orientation == PlotOrientation.VERTICAL:
-                plt.step(xdata, ydata, color='k', alpha=0.9, where='post')
-            elif orientation == PlotOrientation.HORIZONTAL:
-                plt.step(ydata, xdata, color='k', alpha=0.9, where='post')
+                ydata = dist.pmf(x)
+                if orientation == PlotOrientation.VERTICAL:
+                    plt.vlines(xdata, 0, ydata, color='k', alpha=0.9)
+                elif orientation == PlotOrientation.HORIZONTAL:
+                    plt.hlines(xdata, 0, ydata, color='k', alpha=0.9)
 
     elif isinstance(var, monaco.mc_var.OutVar):
-        plt.hist(bins[:-1], bins, weights=counts/sum(counts), density=False,
+        plt.hist(bins[:-1], bins=bins, weights=counts/sum(counts), density=False,
                  orientation=orientation, cumulative=cumulative, histtype='bar',
                  facecolor='k', alpha=0.5, **plotkwargs)
 
@@ -270,20 +278,27 @@ def plot_hist(var         : InVar | OutVar,
         for i in highlight_cases_list:
             plt.plot([points[i], points[i]],
                      [ylim[0], ylim[0] + (ylim[1] - ylim[0])*0.20],
-                     linestyle='-', linewidth=1, color='red', **plotkwargs)
-        for varstat in var.varstats:
+                     linestyle='-', linewidth=1, color='C1', alpha=1,
+                     **plotkwargs)
+        for i, varstat in enumerate(var.varstats):
             nums = get_list(varstat.nums)
-            if length(nums) == 1:
+            if length(nums) == 1:  # Single Statistic
                 plt.plot([nums[0], nums[0]], ylim,
-                         linestyle='-', color='blue', **plotkwargs)
-            elif length(nums) == 3:
+                         linestyle='-', color='C0', alpha=1, **plotkwargs)
+            elif length(nums) == 3:  # Sided Order Statistics
                 plt.plot([nums[1], nums[1]], ylim,
-                         linestyle='-', color='blue', **plotkwargs)
-            if length(nums) in (2, 3):
+                         linestyle='-', color='C0', alpha=1, **plotkwargs)
+            if varstat.confidence_interval_high_nums is not None:
+                ax.fill_between([varstat.confidence_interval_low_nums,
+                                 varstat.confidence_interval_high_nums],
+                                [ylim[0], ylim[0]],
+                                [ylim[1], ylim[1]],
+                                color='C0', alpha=0.3)
+            if length(nums) in (2, 3):  # Sided Order Statistics
                 ax.fill_between([nums[0], nums[-1]],
                                 [ylim[0], ylim[0]],
                                 [ylim[1], ylim[1]],
-                                color='blue', alpha=0.2)
+                                color='C0', alpha=0.3)
         plt.xlabel(var.name)
         plt.ylabel(ylabeltext)
         apply_category_labels(ax, varx=var)
@@ -292,17 +307,22 @@ def plot_hist(var         : InVar | OutVar,
         for i in highlight_cases_list:
             plt.plot([xlim[0], xlim[0] + (xlim[1] - xlim[0])*0.20],
                      [points[i], points[i]],
-                     linestyle='-', linewidth=1, color='red', **plotkwargs)
+                     linestyle='-', linewidth=1, color='C1', alpha=1, **plotkwargs)
         for varstat in var.varstats:
             nums = get_list(varstat.nums)
-            if length(nums) == 1:
+            if length(nums) == 1:  # Single Statistic
                 plt.plot(xlim, [nums[0], nums[0]],
-                         linestyle='-', color='blue', **plotkwargs)
-            elif length(nums) == 3:
+                         linestyle='-', color='C0', alpha=1, **plotkwargs)
+            elif length(nums) == 3:  # Sided Order Statistics
                 plt.plot(xlim, [nums[1], nums[1]],
-                         linestyle='-', color='blue', **plotkwargs)
-            if length(nums) in (2, 3):
-                ax.fill_between(xlim, nums[0], nums[-1], color='blue', alpha=0.2)
+                         linestyle='-', color='C0', alpha=1, **plotkwargs)
+            if varstat.confidence_interval_high_nums is not None:
+                ax.fill_between(xlim,
+                                [varstat.confidence_interval_low_nums,
+                                 varstat.confidence_interval_high_nums],
+                                color='C0', alpha=0.3)
+            if length(nums) in (2, 3):  # Sided Order Statistics
+                ax.fill_between(xlim, nums[0], nums[-1], color='C0', alpha=0.3)
         plt.ylabel(var.name)
         plt.xlabel(ylabeltext)
         apply_category_labels(ax, vary=var)
@@ -420,7 +440,7 @@ def plot_2d_scatter(varx   : InVar | OutVar,
     if highlight_cases_list:
         plt.scatter(slice_by_index(varx_points, highlight_cases_list),
                     slice_by_index(vary_points, highlight_cases_list),
-                    edgecolors=None, c='r', alpha=1, **plotkwargs)
+                    edgecolors=None, c='C1', alpha=0.9, **plotkwargs)
 
     if cov_plot:
         if cov_p is None:
@@ -494,18 +514,23 @@ def plot_2d_line(varx : InVar | OutVar,
                  linestyle='-', color='black', alpha=0.2, **plotkwargs)
     for i in highlight_cases_list:
         plt.plot(varx_points[i], vary_points[i],
-                 linestyle='-', color='red', alpha=1, **plotkwargs)
+                 linestyle='-', color='C1', alpha=0.9, **plotkwargs)
 
     for varstat in vary.varstats:
-        if length(varstat.nums[0]) == 1:
+        if length(varstat.nums[0]) == 1:  # Single Statistic
             plt.plot(varx_points[0], varstat.nums[:],
-                     linestyle='-', color='blue', **plotkwargs)
-        elif length(varstat.nums[0]) == 3:
+                     linestyle='-', color='C0', alpha=0.9, **plotkwargs)
+        elif length(varstat.nums[0]) == 3:  # Sided Order Statistic
             plt.plot(varx_points[0], varstat.nums[:, 1],
-                     linestyle='-', color='blue', **plotkwargs)
-        if length(varstat.nums[0]) in (2, 3):
+                     linestyle='-', color='C0', alpha=0.9, **plotkwargs)
+        if varstat.confidence_interval_high_nums is not None:
+            ax.fill_between(varx_points[0],
+                            varstat.confidence_interval_low_nums,
+                            varstat.confidence_interval_high_nums,
+                            color='C0', alpha=0.3)
+        if length(varstat.nums[0]) in (2, 3):  # Sided Order Statistic
             ax.fill_between(varx_points[0], varstat.nums[:, 0], varstat.nums[:, -1],
-                            color='blue', alpha=0.3)
+                            color='C0', alpha=0.3)
 
     plt.xlabel(varx.name)
     plt.ylabel(vary.name)
@@ -573,7 +598,7 @@ def plot_3d_scatter(varx : InVar | OutVar,
         ax.scatter(slice_by_index(varx_points, highlight_cases_list),
                    slice_by_index(vary_points, highlight_cases_list),
                    slice_by_index(varz_points, highlight_cases_list),
-                   edgecolors=None, c='r', alpha=1, **plotkwargs)
+                   edgecolors=None, c='C1', alpha=0.9, **plotkwargs)
 
     ax.set_xlabel(varx.name)
     ax.set_ylabel(vary.name)
@@ -638,7 +663,7 @@ def plot_3d_line(varx : InVar | OutVar,
                 linestyle='-', color='black', alpha=0.3, **plotkwargs)
     for i in highlight_cases_list:
         ax.plot(varx_points[i], vary_points[i], varz_points[i],
-                linestyle='-', color='red', alpha=1, **plotkwargs)
+                linestyle='-', color='C1', alpha=0.9, **plotkwargs)
 
     ax.set_xlabel(varx.name)
     ax.set_ylabel(vary.name)
@@ -713,7 +738,7 @@ def plot_cov_corr(matrix     : np.ndarray,
 
 
 
-def plot_integration_convergence(outvar     : OutVar,
+def plot_integration_convergence(outvar       : OutVar,
                                  dimension    : int,
                                  volume       : float,
                                  refval       : float          = None,
@@ -724,7 +749,7 @@ def plot_integration_convergence(outvar     : OutVar,
                                  plotkwargs   : dict           = dict(),
                                  ) -> tuple[Figure, Axes]:
     """
-    For a Monte-Carlo integration, plot the running integration estimate along
+    For a Monte Carlo integration, plot the running integration estimate along
     with error bars for a given confidence level.
 
     Parameters
@@ -760,9 +785,9 @@ def plot_integration_convergence(outvar     : OutVar,
     cummean = volume*np.cumsum(outvar.nums)/np.arange(1, outvar.ncases+1)
     err = integration_error(nums=np.array(outvar.nums), dimension=dimension, volume=volume,
                             conf=conf, samplemethod=samplemethod, runningerror=True)
-    ax.plot(cummean, 'r')
-    ax.plot(cummean + err, 'b')
-    ax.plot(cummean - err, 'b')
+    ax.plot(cummean, 'C1')
+    ax.plot(cummean + err, 'C0')
+    ax.plot(cummean - err, 'C0')
 
     ax.set_xlabel('Sample #')
     ax.set_ylabel(f'Convergence of {outvar.name} Integral')
@@ -783,7 +808,7 @@ def plot_integration_error(outvar       : OutVar,
                            plotkwargs   : dict           = dict(),
                            ) -> tuple[Figure, Axes]:
     """
-    For a Monte-Carlo integration where the reference value is known, plot the
+    For a Monte Carlo integration where the reference value is known, plot the
     running integration error along with error bounds for a given confidence
     level.
 
@@ -817,8 +842,8 @@ def plot_integration_error(outvar       : OutVar,
     cummean = volume*np.cumsum(outvar.nums)/np.arange(1, outvar.ncases+1)
     err = integration_error(nums=np.array(outvar.nums), dimension=dimension, volume=volume,
                             conf=conf, samplemethod=samplemethod, runningerror=True)
-    ax.loglog(err, 'b')
-    ax.plot(np.abs(cummean - refval), 'r')
+    ax.loglog(err, 'C0')
+    ax.plot(np.abs(cummean - refval), 'C1')
 
     ax.set_xlabel('Sample #')
     ax.set_ylabel(f'{outvar.name} {round(conf*100, 2)}% Confidence Error')
@@ -861,13 +886,13 @@ def manage_axis(ax   : Optional[Axes],
 
 
 
-def apply_category_labels(ax : Axes,
+def apply_category_labels(ax   : Axes,
                           varx : InVar | OutVar = None,
                           vary : InVar | OutVar = None,
                           varz : InVar | OutVar = None,
                           ) -> None:
     """
-    For nonnumeric Monte-Carlo variables, use the `nummap` to label the axes.
+    For nonnumeric Monte Carlo variables, use the `nummap` to label the axes.
 
     Parameters
     ----------
@@ -961,10 +986,10 @@ def plot_rug_marks(ax          : Axes,
 
 
 
-def plot_2d_cov_ellipse(ax     : Axes,
+def plot_2d_cov_ellipse(ax   : Axes,
                         varx : InVar | OutVar,
                         vary : InVar | OutVar,
-                        p      : float,
+                        p    : float,
                         ) -> None:
     """
     Add a covariance ellipse to a 2D scatter plot.
@@ -1034,7 +1059,7 @@ def get_cases(ncases : int,
 
 
 def manage_invar_space(invar_space : InVarSpace | Iterable[InVarSpace],
-                       nvars : int,
+                       nvars       : int,
                        ) -> list[InVarSpace]:
     '''
     Parse the `invarspace` input for plotting functions. If already an iterable
@@ -1065,7 +1090,7 @@ def manage_invar_space(invar_space : InVarSpace | Iterable[InVarSpace],
 
 
 
-def get_plot_points(var : InVar | OutVar,
+def get_plot_points(var         : InVar | OutVar,
                     invar_space : InVarSpace,
                     ) -> list[float]:
     '''
