@@ -20,7 +20,7 @@ from scipy.stats import rv_continuous, rv_discrete
 
 class Sim:
     """
-    The main Monte-Carlo Simulation object.
+    The main Monte Carlo Simulation object.
 
     Parameters
     ----------
@@ -64,6 +64,8 @@ class Sim:
         The filepath to the simulation .mcsim datafile.
     invarseeds : list[int]
         The random seeds for each of the input variables.
+    outvarseeds : list[int]
+        The random seeds for each of the input variables.
     caseseeds : list[int]
         The random seeds for each of the cases.
     inittime : datetime.datetime
@@ -81,13 +83,13 @@ class Sim:
     casespostprocessed : set[int]
         The case numbers which were sucessfully postprocessed.
     invars : dict[str, monaco.mc_var.InVar]
-        The Monte-Carlo Input Variables.
+        The Monte Carlo Input Variables.
     outvars : dict[str, monaco.mc_var.OutVar]
-        The Monte-Carlo Output Variables.
+        The Monte Carlo Output Variables.
     constvals : dict[str, Any]
         The constant values to pass to each of the cases.
     cases : list[monaco.mc_case.Case]
-        The Monte-Carlo Cases.
+        The Monte Carlo Cases.
     ninvars : int
         The number of input variables.
     noutvars : int
@@ -148,8 +150,9 @@ class Sim:
         if self.savesimdata:
             self.filepath = self.resultsdir / f'{self.name}.mcsim'
 
-        self.invarseeds : list[int] = []
-        self.caseseeds  : list[int] = []
+        self.invarseeds  : list[int] = []
+        self.outvarseeds : list[int] = []
+        self.caseseeds   : list[int] = []
 
         self.inittime  : datetime = datetime.now()
         self.starttime : datetime = None
@@ -265,11 +268,12 @@ class Sim:
         """
         self.ninvars += 1
         if seed is None:
-            seed = (self.seed + self.ninvars) % 2**32  # seed is dependent on the order added
+            # seed is dependent on the order added
+            seed = (self.seed + self.ninvars) % 2**32
         self.invarseeds.append(seed)
         invar = InVar(name=name, dist=dist, distkwargs=distkwargs, ndraws=self.ndraws,
-                        nummap=nummap, samplemethod=self.samplemethod, ninvar=self.ninvars,
-                        seed=seed, firstcaseismedian=self.firstcaseismedian, autodraw=False)
+                      nummap=nummap, samplemethod=self.samplemethod, ninvar=self.ninvars,
+                      seed=seed, firstcaseismedian=self.firstcaseismedian, autodraw=False)
         self.invars[name] = invar
 
 
@@ -439,7 +443,7 @@ class Sim:
                  cases : None | int | Iterable[int] = None,
                  ) -> None:
         """
-        Generate all the Monte-Carlo case objects.
+        Generate all the Monte Carlo case objects.
 
         Parameters
         ----------
@@ -474,7 +478,7 @@ class Sim:
                         cases : None | int | Iterable[int],
                         ) -> None:
         """
-        Preprocess all the Monte-Carlo cases.
+        Preprocess all the Monte Carlo cases.
 
         Parameters
         ----------
@@ -515,7 +519,7 @@ class Sim:
                        case : Case,
                        ) -> Case:
         """
-        Preprocess a single Monte-Carlo case.
+        Preprocess a single Monte Carlo case.
 
         Parameters
         ----------
@@ -549,7 +553,7 @@ class Sim:
                  calledfromrunsim : bool = False,
                  ) -> None:
         """
-        Run all the Monte-Carlo cases.
+        Run all the Monte Carlo cases.
 
         Parameters
         ----------
@@ -600,7 +604,7 @@ class Sim:
                 case : Case,
                 ) -> None:
         """
-        Run a single Monte-Carlo case.
+        Run a single Monte Carlo case.
 
         Parameters
         ----------
@@ -645,7 +649,7 @@ class Sim:
                          cases : None | int | Iterable[int],
                          ) -> None:
         """
-        Postprocess all the Monte-Carlo cases.
+        Postprocess all the Monte Carlo cases.
 
         Parameters
         ----------
@@ -687,7 +691,7 @@ class Sim:
                         case : Case,
                         ) -> None:
         """
-        Postprocess a single Monte-Carlo case.
+        Postprocess a single Monte Carlo case.
 
         Parameters
         ----------
@@ -716,7 +720,11 @@ class Sim:
 
     def genOutVars(self) -> None:
         """Generate the output variables."""
-        for varname in self.cases[0].outvals.keys():
+        for i_var, varname in enumerate(self.cases[0].outvals.keys()):
+            # seed is dependent on the order added
+            seed = (self.seed - 1 - i_var) % 2**32
+            self.outvarseeds.append(seed)
+
             vals = []
             for i in range(self.ncases):
                 vals.append(self.cases[i].outvals[varname].val)
@@ -737,8 +745,8 @@ class Sim:
                 valmap = self.cases[0].outvals[varname].valmap
 
             self.outvars[varname] = OutVar(name=varname, vals=vals, valmap=valmap,
-                                               ndraws=self.ndraws,
-                                               firstcaseismedian=self.firstcaseismedian)
+                                           ndraws=self.ndraws, seed=seed,
+                                           firstcaseismedian=self.firstcaseismedian)
             for i in range(self.ncases):
                 self.cases[i].outvars[varname] = self.outvars[varname]
 
